@@ -47,7 +47,10 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
         response_data = response.read()
         conn.close()
 
-        if response.status is 204:
+        if response.status == 403:
+            return 403, None
+
+        if response.status == 204:
             if response_token is True:
                 error_message = 'Backend server didn\'t respond with a token'
                 raise Exception
@@ -66,7 +69,7 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
                 request.user.pk = response_json[proxy_server.USER_TOKEN]
                 request.session[proxy_server.EXPIRATION_DATE] = response_json[proxy_server.EXPIRATION_DATE]
 
-            if response.status is 200:
+            if response.status == 200:
                 if response_token is True and proxy_server.USER_TOKEN not in response_json:
                     error_message = 'Server expected user token in response'
                     raise Exception
@@ -130,7 +133,14 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
         response_data = response.read()
         conn.close()
 
-        if response.status is 204:
+        if response.status == 403:
+            resp = HttpResponse(status=response.status, reason=response.reason)
+            for header, value in response.getheaders():
+                resp[header] = value
+
+            return resp
+
+        if response.status == 204:
             if response_token is True:
                 error_message = 'Backend server didn\'t respond with a token'
                 raise Exception
@@ -147,7 +157,7 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                 error_message = 'Unknown response format'
                 raise Exception
 
-            if response.status is 200:
+            if response.status == 200:
                 if response_token is True and proxy_server.USER_TOKEN not in response_json:
                     error_message = 'Server expected user token in response'
                     raise Exception
