@@ -1,6 +1,6 @@
 from functools import wraps
 from rest_framework.decorators import api_view
-from django.http import HttpResponseServerError
+from django.http import HttpResponse
 from django.conf import settings
 from importlib import import_module
 import proxy_server, json
@@ -45,7 +45,7 @@ def expose_service(methods, public=False):
                                         error_message = 'Could not invoke token validation service'
                                         raise Exception
 
-                                    if response.status == 403:
+                                    if response.status_code == 403:
                                         code = 403
                                         error_message = 'Token invalid'
                                         raise Exception
@@ -67,6 +67,7 @@ def expose_service(methods, public=False):
                     raise Exception
 
             except Exception as e:
+                print 'ERROR', e, error_message, code
                 if error_message is None:
                     if e.message is not None:
                         error_message = e.message
@@ -82,7 +83,9 @@ def expose_service(methods, public=False):
                     }
                 }
 
-                return HttpResponseServerError(json.dumps(error), content_type='application/json')
+                print 'ERROR JSON', error
+
+                return HttpResponse(json.dumps(error), content_type='application/json', status=code, reason=error_message)
 
         return wraps(view_func)(wrapper)
     return decorator
